@@ -90,6 +90,7 @@ class Resource(object):
         'inspection_finished_at': 'Inspection Finished At',
         'inspection_started_at': 'Inspection Started At',
         'instance_info': 'Instance Info',
+        'instance_name': 'Instance Name',
         'instance_uuid': 'Instance UUID',
         'internal_info': 'Internal Info',
         'last_error': 'Last Error',
@@ -131,6 +132,8 @@ class Resource(object):
         'value': 'Value',
         'volume_id': 'Volume ID',
         'volume_type': 'Driver Volume Type',
+        'category': 'Category',
+        'vendor': 'Vendor',
         'local_link_connection': 'Local Link Connection',
         'pxe_enabled': 'PXE boot enabled',
         'portgroup_uuid': 'Portgroup UUID',
@@ -158,6 +161,7 @@ class Resource(object):
         'parent_node': 'Parent Node',
         'children': 'Child Nodes',
         'firmware_interface': 'Firmware Interface',
+        'health': 'Health',
         'public': 'Public',
         'disable_power_off': 'Disable Power Off',
         'priority': 'Priority',
@@ -269,10 +273,12 @@ NODE_DETAILED_RESOURCE = Resource(
      'extra',
      'fault',
      'firmware_interface',
+     'health',
      'inspect_interface',
      'inspection_finished_at',
      'inspection_started_at',
      'instance_info',
+     'instance_name',
      'instance_uuid',
      'last_error',
      'lessee',
@@ -347,6 +353,8 @@ PORT_DETAILED_RESOURCE = Resource(
      'created_at',
      'extra',
      'node_uuid',
+     'category',
+     'vendor',
      'local_link_connection',
      'portgroup_uuid',
      'pxe_enabled',
@@ -384,6 +392,8 @@ PORTGROUP_DETAILED_RESOURCE = Resource(
      'internal_info',
      'mode',
      'properties',
+     'physical_network',
+     'category',
      ],
     sort_excluded=[
         'extra',
